This function estimates local causal effect of treatment under standard
regression discontinuity (RD) setting.
Usage
rdestimate(y, x, c, group_name = NULL, data)
Value
A data frame with the RD estimates for each group, including the
sample size of each group, baseline cutoff, RD estimate, standard error,
and p-value.
Arguments
y
A character string specifying the name of column containing the
outcome variable.
x
A character string specifying the name of column containing the
running variable.
c
A character string specifying the name of column containing the
cutoff variable.
group_name
A character ctring specifying the name of the column
containing group names (e.g., department names) for each cutoff. If not
provided, the groups are assigned names "Group 1", "Group 2", ... in
ascending order of cutoff values.