Learn R Programming

rdlearn (version 0.1.1)

simdata_A: Simulation Data A

Description

This dataset is based on the ACCES Program and generated according to scenario A described in Appendix D of Zhang et al. (2022). In this scenario, the baseline policy (cutoff) is set equal to the oracle policy.

Usage

simdata_A

Arguments

Format

A data frame with 2000 rows and 3 columns:

Y

outcome variable

X

running variable

C

cutoff value

References

Zhang, Y., Ben-Michael, E. and Imai, K. (2022) 'Safe Policy Learning under Regression Discontinuity Designs with Multiple Cutoffs', arXiv [stat.ME]. Available at: http://arxiv.org/abs/2208.13323.